#! node

const chalk = require('chalk');
const program = require('commander');
const spawn = require('cross-spawn');
const join = require('path').join;
const fs = require('fs');
const exists = fs.existsSync;
const path = require('path');

program
  .usage('<command> [options]')
  .on('--help', printHelp)
  .parse(process.argv);

const aliases = {
  r: 'route'
};
const args = process.argv.slice(3);
let subcmd = program.args[0];
if (aliases[subcmd]) subcmd = aliases[subcmd];

if (!subcmd) {
  program.help();
} else {
  const bin = executable(subcmd);
  if (bin) {
    wrap(spawn(`node`, [bin].concat(args), {stdio: 'inherit', customFds: [0, 1, 2]}));
  } else {
    program.help();
  }
}

function wrap(sp) {
  sp.on('close', function(code) {
    process.exit(code);
  });
}

function printHelp() {
  var text = fs.readFileSync(path.resolve(__dirname, `./config.js`) ,'utf-8');
  const template = text.match(/"templatePath":"([^"]*)"/)[1];
  console.log();
  console.log(`  current template: ${template}`);
  console.log();
  console.log('  All commands can be run with -h (or --help) for more information.')
}

function executable(subcmd) {
  var file = join(__dirname , `./config/${subcmd}.js`);
  if (exists(file)) {
    return file;
  }
}
