#! node

const chalk = require('chalk');
const program = require('commander');
const spawn = require('cross-spawn');
const join = require('path').join;
const exists = require('fs').existsSync;

if (process.argv.slice(2).join('') === '-v') {
  console.log('mei: ' + require('./package').version);
  return;
}

program
  .usage('<command> [options]')
  .on('--help', printHelp)
  .parse(process.argv);

const aliases = {
  in: 'insert',
  c : 'create'
};
const args = process.argv.slice(3);
let subcmd = program.args[0];
if (aliases[subcmd]) subcmd = aliases[subcmd];

if (!subcmd) {
  program.help();
} else {
  const bin = executable(subcmd);
  if (bin) {
    wrap(spawn(`node`, [bin].concat(args), {stdio: 'inherit', customFds: [0, 1, 2]}));
  } else {
    program.help();
  }
}

function wrap(sp) {
  sp.on('close', function(code) {
    process.exit(code);
  });
}

function printHelp() {
  console.log('  Commands:');
  console.log();
  console.log('    create          创建路由(route)');
  console.log('    new            Creates a new application');
  console.log('    generate       Generates new code (short-cut alias: "g")');
  console.log();
  console.log('  All commands can be run with -h (or --help) for more information.')
}

function executable(subcmd) {
  var file = join(__dirname, 'honey-' + subcmd + '.js');
  if (exists(file)) {
    return file;
  }
}
