#!/usr/bin/env node

const chalk = require('chalk');
const program = require('commander');
const spawn = require('cross-spawn');
const join = require('path').join;
const exists = require('fs').existsSync;

if (process.argv.slice(2).join('') === '-v') {
  console.log('honey: ' + require('./package').version);
  return;
}

program
  .usage('<command> [options]')
  .on('--help', printHelp)
  .parse(process.argv);

const aliases = {
  //in: 'insert',
};
const args = process.argv.slice(3);
let subcmd = program.args[0];
if (aliases[subcmd]) subcmd = aliases[subcmd];

if (!subcmd) {
  program.help();
} else {
  const bin = executable(subcmd);
  if (bin) {
    wrap(spawn(`node`, [bin].concat(args), {stdio: 'inherit', customFds: [0, 1, 2]}));
  } else {
    program.help();
  }
}

function wrap(sp) {
  sp.on('close', function(code) {
    process.exit(code);
  });
}

function printHelp() {
  console.log('  Commands:');
  console.log('    create page           创建页面 (含创建路由), 页面名称请使用跎峰命名');
  console.log('    create route          创建路由');
  console.log('    create component      创建通用组件');
  console.log('    create message        创建国际语言');
  console.log('    switch route          切换路由');
  console.log('    config template       配置模板地址');
  console.log('    delete page           删除页面');
  console.log('  All commands can be run with --help for more information.')
}

function executable(subcmd) {
  var file = join(__dirname, 'honey-' + subcmd + '.js');
  if (exists(file)) {
    return file;
  }
}
